/**
 *        Copyright (c) 1993-2006 IONA Technologies PLC.
 *                       All Rights Reserved.
 */

package demo.asset.client;

import java.io.File;
import java.net.URL;
import javax.xml.namespace.QName;
import com.iona.asset.types.Employee;
import com.iona.asset.types.Vehicle;
import com.iona.asset.CompanyAssetService;
import com.iona.asset.CompanyAssetPortType;
import com.iona.asset.GetEmployeeFault;
import com.iona.asset.GetVehicleFault;

public final class Client {

    private static final QName SERVICE_NAME 
        = new QName("http://iona.com/asset", "CompanyAssetService");

    private Client() {
    } 

    public static void main(String args[]) throws Exception {
        
        if (args.length == 0) { 
            System.out.println("please specify wsdl");
            System.exit(1); 
        }

        URL wsdlURL;
        File wsdlFile = new File(args[0]);
        if (wsdlFile.exists()) {
            wsdlURL = wsdlFile.toURL();
        } else {
            wsdlURL = new URL(args[0]);
        }
        
        System.out.println(wsdlURL);
        CompanyAssetService ca = new CompanyAssetService(wsdlURL, SERVICE_NAME);
        CompanyAssetPortType port = ca.getCompanyAssetPort();

        try {
            Employee e = port.getEmployee(1);
            System.out.println("employee name: " + e.getName());
            System.out.println("employee license: " + e.getLicense());
            Vehicle v = port.getVehicle(2);
            System.out.println("vehicle capacity: " + v.getCapacity());
        } catch (GetEmployeeFault ex1) {
            System.err.println("Received GetEmployeeFault exception");
            System.exit(1);
        } catch (GetVehicleFault ex2) {
            System.err.println("Received GetVehicleFault exception");
            System.exit(1);
        }
        System.exit(0);
    }

}
