/**
 *        Copyright (c) 1993-2006 IONA Technologies PLC.
 *                       All Rights Reserved.
 */

package demo.proxy.server;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.OutputStream;

import javax.xml.ws.Endpoint;

import java.net.URL;

import org.apache.cxf.Bus;
import org.apache.cxf.BusFactory;
import org.apache.cxf.helpers.IOUtils;
import org.apache.cxf.message.ExchangeImpl;
import org.apache.cxf.message.Message;
import org.apache.cxf.message.MessageImpl;
import org.apache.cxf.service.model.EndpointInfo;
import org.apache.cxf.transport.Conduit;
import org.apache.cxf.transport.Destination;
import org.apache.cxf.transport.DestinationFactory;
import org.apache.cxf.transport.DestinationFactoryManager;
import org.apache.cxf.transport.MessageObserver;


public class HtmlServer implements org.springframework.beans.factory.InitializingBean,  org.springframework.beans.factory.DisposableBean {
    static String deliveryHtml;
	
	public HtmlServer(String locationWsdl, String assetWsdl, String deliveryHtml) {
        
		// We publish these proxy endpoints on the same domain as the 
        // speedy_delivery.html so that javascript can make 
        // XMLHttpRequests to them.  These calls are forwarded on to
        // the "real" services.
        if (locationWsdl != null) {
            Endpoint.publish("http://localhost:8888/LocationServicePort",
                             new ProxyLocationServiceImpl(locationWsdl)); 
        }
        if (assetWsdl != null) {
            Endpoint.publish("http://localhost:8888/ProxyAssetPort",
                             new ProxyAssetServiceImpl(assetWsdl)); 
        } 

        File deliveryHtmlFile = new File(deliveryHtml);
        try {
            if (deliveryHtmlFile .exists()) {
                deliveryHtml = deliveryHtmlFile.toURL().getFile();
            } else {

                deliveryHtml = getClass().getResource(deliveryHtml).getFile();
            }
        } catch (java.net.MalformedURLException ex) {
            System.err.println("MalformedURLException " + ex);
            return;
        }
        
        System.out.println("delivery Html file : " + deliveryHtml);        
        
        this.deliveryHtml = deliveryHtml;
        
        try {
			serveHTML();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
    public void afterPropertiesSet() throws Exception {
        // empty
    }
    
    public void destroy() throws Exception {

    }
    
    /* 
     public static void main(String[] args) throws Exception {
        String locationWsdl = null;
        String assetWsdl = null;
        for (int i = 0; i < args.length; ) {
            if ("-locationWsdl".equals(args[i]) && (i + 1) < args.length) {
                locationWsdl = args[i+1];
                i++;
            } else if ("-assetWsdl".equals(args[i]) && (i + 1) < args.length) {
                assetWsdl = args[i+1];
                i++;
            }
            i++;
        }
            
        // We publish these proxy endpoints on the same domain as the 
        // speedy_delivery.html so that javascript can make 
        // XMLHttpRequests to them.  These calls are forwarded on to
        // the "real" services.
        if (locationWsdl != null) {
            Endpoint.publish("http://localhost:8888/LocationServicePort",
                             new ProxyLocationServiceImpl(locationWsdl)); 
        }
        if (assetWsdl != null) {
            Endpoint.publish("http://localhost:8888/ProxyAssetPort",
                             new ProxyAssetServiceImpl(assetWsdl)); 
        } 
        serveHTML();
    } */
    
    /**
     * Serve out a static HTML file.  Javascript XMLHttpRequests
     * can only make requests within one domain - in this case 
     * requests are made to the proxy services.
     */
    private static void serveHTML() throws Exception {
        Bus bus =  BusFactory.getDefaultBus();
        DestinationFactoryManager dfm = bus.getExtension(DestinationFactoryManager.class);
        DestinationFactory df = dfm.getDestinationFactory("http://cxf.apache.org/transports/http/configuration");
        
        EndpointInfo ei = new EndpointInfo();
        ei.setAddress("http://localhost:8888/speedy_delivery.html");
        
        Destination d = df.getDestination(ei);
        System.out.println("Destination = " + d.toString());
        d.setMessageObserver(new MessageObserver() {

            public void onMessage(Message message) {
                try {
                    // HTTP seems to need this right now...
                    ExchangeImpl ex = new ExchangeImpl();
                    ex.setInMessage(message);
                    
                    Conduit backChannel = message.getDestination().
                        getBackChannel(message, null, null);

                    MessageImpl res = new MessageImpl();
                    res.put(Message.CONTENT_TYPE, "text/html");
                    backChannel.prepare(res);

                    OutputStream out = res.getContent(OutputStream.class);
                    FileInputStream is = new FileInputStream(deliveryHtml);
                    IOUtils.copy(is, out, 2048);

                    System.out.println("Out Stream = " + out.toString());
                    out.flush();
                    
                    out.close();
                    is.close();
                
                    backChannel.close(res);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
            
        });
    }
}
