/**
 *        Copyright (c) 1993-2006 IONA Technologies PLC.
 *                       All Rights Reserved.
 */

package demo.proxy.server;

import java.io.File;
import java.net.URL;
import java.util.List;
import java.util.logging.Logger;

import javax.xml.namespace.QName;

import com.iona.asset.types.Employee;
import com.iona.asset.types.Vehicle;
import com.iona.asset.CompanyAssetPortType;
import com.iona.asset.CompanyAssetService;
import com.iona.asset.ProxyAssetService;
import com.iona.asset.GetEmployeeFault;
import com.iona.asset.GetVehicleFault;

@javax.jws.WebService(portName = "ProxyAssetPort",
                      serviceName = "ProxyAssetService",
                      targetNamespace = "http://iona.com/asset", 
                      endpointInterface = "com.iona.asset.CompanyAssetPortType")
public class ProxyAssetServiceImpl implements CompanyAssetPortType {

    private static final Logger LOG = 
        Logger.getLogger(ProxyAssetServiceImpl.class.getPackage().getName());

    private static final QName PROXY_SERVICE_NAME 
        = new QName("http://iona.com/asset", "ProxyAssetService");

    private static final QName REAL_SERVICE_NAME 
    = new QName("http://iona.com/asset", "CompanyAssetService");
    
    private CompanyAssetPortType port;
    private URL wsdlURL;
    
    ProxyAssetServiceImpl(String wsdlLocation) {
        File wsdlFile = new File(wsdlLocation);
        try {
            if (wsdlFile.exists()) {
                wsdlURL = wsdlFile.toURL();
            } else {

                wsdlURL = getClass().getResource(wsdlLocation);
            }
        } catch (java.net.MalformedURLException ex) {
            System.err.println("MalformedURLException " + ex);
            return;
        }
        
        System.out.println("ProxyAssetService wsdl file : " + wsdlURL);
        ProxyAssetService ca = new ProxyAssetService(wsdlURL, PROXY_SERVICE_NAME);
        port = ca.getProxyAssetPort();
    }

    public Employee getEmployee(int id) throws GetEmployeeFault {
    	CompanyAssetService ca = new CompanyAssetService(wsdlURL, REAL_SERVICE_NAME);
    	CompanyAssetPortType localport = ca.getCompanyAssetPort();
    	if (localport != null) {
            return localport.getEmployee(id);
        } else {
            throw new GetEmployeeFault("null port - cannot forward request");
        }
    }

    public void addEmployee(Employee e) {
        // Not implemented
    }
    
    public void removeEmployee(int id) {
        // Not implemented
    }
    
    public Vehicle getVehicle(int id) throws GetVehicleFault {
    	CompanyAssetService ca = new CompanyAssetService(wsdlURL, REAL_SERVICE_NAME);
    	CompanyAssetPortType localport = ca.getCompanyAssetPort();
        if (localport != null) {
            return localport.getVehicle(id);
        } else {
            throw new GetVehicleFault("null port - cannot forward request");
        }
    }
    
    public void addVehicle(Vehicle v) {
        // Not implemented
    }
    
    public void removeVehicle(int id) {
        // Not implemented
    }
}
