/**
 *        Copyright (c) 1993-2006 IONA Technologies PLC.
 *                       All Rights Reserved.
 */

package demo.proxy.server;

import java.io.File;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

import javax.xml.namespace.QName;
import javax.xml.ws.Endpoint;

import com.iona.location_types.Location;
import com.iona.location_service.GetLocationsPortType;
import com.iona.location_service.GetLocationsService;
import com.iona.location_service.ProxyGetLocationsService;

@javax.jws.WebService(portName = "ProxyGetLocationsPort",
                      serviceName = "ProxyGetLocationsService",
                      targetNamespace = "http://iona.com/location_service", 
                      endpointInterface = "com.iona.location_service.GetLocationsPortType")
public class ProxyLocationServiceImpl implements GetLocationsPortType {

    private static final Logger LOG = 
        Logger.getLogger(ProxyLocationServiceImpl.class.getPackage().getName());

    private static final QName PROXY_SERVICE_NAME 
        = new QName("http://iona.com/location_service", "ProxyGetLocationsService");

    private static final QName REAL_SERVICE_NAME 
    	= new QName("http://iona.com/location_service", "GetLocationsService");
    
    private GetLocationsPortType port;
    private URL wsdlURL;
    
    ProxyLocationServiceImpl(String wsdlLocation) {
        File wsdlFile = new File(wsdlLocation);
        try {
            if (wsdlFile.exists()) {
                wsdlURL = wsdlFile.toURL();
            } else {
                wsdlURL = getClass().getResource(wsdlLocation);
            }
        } catch (java.net.MalformedURLException ex) {
            System.err.println("MalformedURLException " + ex);
            return;
        }
        
        System.out.println("ProxyLocationService wsdl file : " + wsdlURL);
        ProxyGetLocationsService ls = new ProxyGetLocationsService(wsdlURL, PROXY_SERVICE_NAME);
        port = ls.getProxyGetLocationsPort();
    }
    
    public List<Location> getLocations() {

    	/*
        if (port != null) {
            return port.getLocations();
        } else {
            return new ArrayList<Location>();
        }
        */
        
		// Call the real Location Service from this Client Proxy
		GetLocationsService ls = new GetLocationsService(wsdlURL, REAL_SERVICE_NAME);
		GetLocationsPortType localPort = ls.getGetLocationsPort();
        if (localPort != null) {
            return localPort.getLocations();
        } else {
            return new ArrayList<Location>();
        }
    }
}
